# Plover MIDI

Add support for MIDI keyboards/machines to [Plover](http://www.openstenoproject.org/).


## Release history

### 1.0.4

* **really** disable unused and broken i18n support...

### 1.0.3

* disable unused and broken i18n support

### 1.0.2

* fix machine settings not being saved

### 1.0.0

* drop support for the Michela Keyboard machine (now part of the [Michela plugin](https://pypi.org/project/plover-michela/))

### 0.2.6

* add support for machine configuration through the Qt GUI
